@@ -152,7 +152,7 @@ require Exporter;
 
 @EXPORT_OK = qw(make_diff merge_diff);
 
-$VERSION = '0.07';
+$VERSION = '0.09';
 
 our $NSURL = 'http://www.locus.cz/XML/DifferenceMarkup';
 
@@ -978,8 +978,15 @@ sub _fill {
 	        $_->name . "\n";
 	}
 
-	my $pair = $_->name . "\n" . $_->getData;
-	$self->{namespaces}->{$pair} = 1;
+	if (defined $_->name) {
+	    my $pair = $_->name . "\n" . $_->getData;
+	    $self->{namespaces}->{$pair} = 1;
+	} else {
+	    if ($_->getData eq $self->{nsurl}) {
+	      die "XML::DifferenceMarkup diff: input tree contains the reserved namespace " . $self->{nsurl} . "\n";
+	    }
+	}
+
     }
 
     my $ch = $n->firstChild;
